/*
 * FIRA2 is a program to inject/hide a file into a standard bitmap file. 
 * It includes file compression and encryption as well.
 * Copyright (C) <year> <name of author>
 *
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software 
 * Foundation; either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with 
 * this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/*
 * FILE: MyFileFilter.java
 * INHERITS: FileFilter
 * PURPOSE: To provide a more flexible file filter for the JFileChooser dialog. Each object
 *          constructed represent one file filter by file extension.
 * AUTHOR: LCC Corps
 * DATE: 27 November 2005
 * LAST MODIFIED: June 22, 2006
 * REFERENCE: 
 * COMMENT: No setter and getter methods because want to limit the attributes initialization 
 *          ONLY during construction. Don't want the attributes to change after construction.
 */


package gui.custom;

import java.io.File;
import javax.swing.filechooser.FileFilter;


public class FileExtFilter extends FileFilter
{
  private String extension, description;   // accepted file extension and file description


  // CONSTRUCTOR #1
  // IMPORT: none

  public FileExtFilter ()
  {
    super ();
    extension = description = null;
  }


  // CONSTRUCTOR #2
  // PURPOSE: to construct a file filter object with given extension and description
  // IMPORT: accepted file extension, file description

  public FileExtFilter (String ext, String desc)
  {
    extension = new String (ext);
    description = new String (desc);
  }


  // METHOD: accept ()
  // PURPOSE: to return 'true' for the file that is accepted/passed thru the file filter, 'false' otherwise
  // IMPORT: none
  // EXPORT: 'true' for accepted file, false otherwise

  public boolean accept (File f)
  {
    String filename = null,
           ext = null; 
    boolean temp = false;

    if (f.isDirectory ())
      temp = true;   // a 'directory' is qualified/pass thru the filter

    else if (f.isFile ()) {
      filename = f.getName ();
      ext = filename.substring (filename.lastIndexOf ('.') + 1, filename.length ());   // get file extension
      temp = ext.equalsIgnoreCase (extension);
    }
    
    return temp;       
  }


  // METHOD: getDescription ()
  // PURPOSE: to return the description of the file filter object
  // IMPORT: none
  // EXPORT: file filter description

  public String getDescription ()
  {
    return description;
  }


  // METHOD: getExtension ()
  // PURPSE: to return the extension of the file filter to be used to create filename 
  //         when a filename with NO extension is entered using JFileChooser
  // IMPORT: none
  // EXPORT: extension of the file filter

  public String getExtension ()
  {
    return extension;
  }
}