/*
 * FIRA2 is a program to inject/hide a file into a standard bitmap file. 
 * It includes file compression and encryption as well.
 * Copyright (C) <year> <name of author>
 *
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software 
 * Foundation; either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with 
 * this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/*
 * FILE: MyFileChooser.java
 * INHERITS: JFileChooser
 * PURPOSE: to override the approveSelection() method for further checking, ie to check if 
 *          file exists before open file and to check if file already exists when saving file,
 *          prompt user to replace existing file is file exists
 * AUTHOR: LCC Corps
 * DATE: 3 December 2005
 * LAST MODIFIED: June 22, 2006
 * COMMENT:
 *
 */

package gui.custom;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import javax.swing.JOptionPane;
import java.io.File;

import javax.swing.plaf.basic.BasicFileChooserUI; //.AcceptAllFileFilter;   // for basic all file filter


public class MyFileChooser extends JFileChooser
{

  // METHOD: approveSelection ()
  // PURPOSE: to override the built-in approveSelection() to implement some 'File not found'
  //          (when open a file) and 'Replace existing file' (when saving a file) checking prior to
  //          approve the file selected by the user
  // IMPORT: none
  // EXPORT: none

  public void approveSelection ()
  {
    File f = super.getSelectedFile ();
    FileFilter filters[] = getChoosableFileFilters ();
    boolean fileAccepted = false;

    if (filters != null && f.exists ()) {
        for (int i = 0; i < filters.length && !fileAccepted; i++) {
            // accept() will also return FALSE if file does not exists!!!
            fileAccepted = filters[i].accept (f);
        }

        // legal file extension not found, return to calling function
    	if (!fileAccepted) {
            JOptionPane.showMessageDialog (null, "File format not supported ! ! !", "# ERROR #", JOptionPane.WARNING_MESSAGE);
            return;
    	}
    }

    if (getDialogType () == OPEN_DIALOG) {
      if (!f.exists ())
        JOptionPane.showMessageDialog (null, "File not found ! ! !", "# ERROR #", JOptionPane.WARNING_MESSAGE);
      else
        super.approveSelection ();

    } else if (getDialogType () == SAVE_DIALOG) {
      if (!f.exists ())
        super.approveSelection ();

      else {
        int choice = JOptionPane.showConfirmDialog (null,
                        "File already exists.\nReplace existing file ?",
                        "Replace file", JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE);

        if (choice == JOptionPane.YES_OPTION) {
          f.delete ();
          // f.createNewFile ();
          super.approveSelection ();
        }
      }
    }
  }


  // METHOD: getSelectedFile ()
  // PURPOSE: to override the built-in getSelectedFile() to append a selected file (but no file
  //          extension specified) with the file filter by extension selected. 
  //          E.g. if user enter a filename "abc" AND selected "Bitmap image file (*.bmp)" filter, 
  //          then click "Open file", the File object returned will be a File object with filename 
  //          "abc.bmp" instead of just "abc"
  // IMPORT: none
  // EXPORT: a file object selected by the user
  // COMMENT: This implementation only works with the FileExtFilter objects!

  public File getSelectedFile ()
  {
    File f = super.getSelectedFile ();

    if (f != null) {
      String filename = f.getName ();
      FileFilter ff = getFileFilter ();

      // if filename does not contains an extension AND the file filter selected is an instance of FileExtFilter
      if (filename.indexOf ('.') < 0 && FileExtFilter.class.isInstance (ff)) { 
        // get file extension from selected file filter
        f = new File (f.getAbsolutePath () +"." +((FileExtFilter) ff).getExtension ());
      }
    }

    return f;
  }
}
