/*
 * FIRA2 is a program to inject/hide a file into a standard bitmap file. 
 * It includes file compression and encryption as well.
 * Copyright (C) 2006 LCC Coprs
 * The author can be reached at aurora.lai@gmail.com
 *
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License as published by the Free Software 
 * Foundation; either version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with 
 * this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */


/* 
 * FILE: MyFile.java
 * INHERITS: File
 * PURPOSE: To add some extra features/behaviour on the existing File class
 * AUTHOR: LCC Corps
 * DATE: 26 November 2005
 * LAST UPDATED: June 20, 2006
 * REFERENCE:
 * COMMENT:
 *
 */


package sys;

import java.io.File;
import java.io.IOException;

import java.text.DecimalFormat;

public class MyFile extends File
{
    // Contructor #1
    public MyFile (String filename)
    {
        super (filename);
    }
	
	
    // Contructor #2
    public MyFile (File parent, String child)
    {
        super (parent, child);
    }
	
    // Constructor #3
    public MyFile (File f)
    {
        this (f.getAbsolutePath ());
    }
	

    // METHOD: truncateName ()
    // PURPOSE: to get a shortened filename of the file. ONLY a long filename 
    //          (name with more than 20 chars, excluding the extension) will be 
    //          shortened.
    // IMPORT: none
    // EXPORT: a shortened filename.
    // COMMENT: Assume a filename is made up by name.extension, so split up the
    //          filename into 'name' and 'extension'. IF name.length() > 20 chars,
    //          then trim the filename to be 'name (at most 20 chars)' + '.' + 
    //          'extension'.
    public String truncateName ()
    {
    	final int MAX_LENGTH = 20;
    	String fullName;
    	int index;
        String name;
    	String ext = "";
        
        fullName = getName ();
        index = fullName.lastIndexOf ('.');
        if (index < 0) {
            name = fullName;
        } else {
            name = fullName.substring (0, index); 
            ext = fullName.substring (index, fullName.length());
        }
        
    	if (name.length () > MAX_LENGTH) {
            name = fullName.substring (0, MAX_LENGTH);
    	}

        return (name +ext); 
    }


    // METHOD: getParent()
    // PURPOSE: to get the absolute directory in which the file resides.
    // IMPORT: none
    // EXPORT: the absolute directory of this file
    public String getParent ()
    {
        String parent = getAbsolutePath ();
        int i = parent.lastIndexOf ('\\');
        parent = parent.substring (0, i);

        return parent;
    }


    // METHOD: getParentFile()
    // PURPOSE: to get the abstract file object for the absolute directory 
    //			in which the file resides.
    // IMPORT: none
    // EXPORT: the MyFile object of the absolute directory of this file
    public MyFile getParentFile ()
    {
        return (new MyFile (getParent ()));
    }


    // METHOD: getExtension ()
    // PURPOSE: get the extension of this file
    // IMPORT: none
    // EXPORT: the file extension of this file, null if this file has no 
    //         extension (e.g. a directory)
    // ASSERTION: The char '.' is always used to separate the filename with 
    //            its extension, and it is NOT used for any other function
    public String getExtension ()
    {
        String ext = null;
        String name = getName ();
        int index = name.lastIndexOf ('.');
		
        if (index > 0) {
            ext = name.substring (index + 1, name.length());
        }
		
        return ext;
    }

    
    // METHOD: renameExt() ()
    // PURPOSE: to rename the file extension.
    // IMPORT: a new file extension (without the '.' char)
    // EXPORT: The name of the file with its extension renamed
    public String renameExt (String newExt)
    {
        return (removeExt() +"." +newExt);
    }


    // METHOD: removeExt() ()
    // PURPOSE: to remove the file extension.
    // IMPORT: none
    // EXPORT: The name of the file with its extension removed
    public String removeExt ()
    {
        String name = getName ();
        int end = name.lastIndexOf ('.');
        
        if (end > 0)
            name = name.substring (0, end);
		
        return (name);
    }
        

    // METHOD: renameTo() ()
    // PURPOSE: to rename the file denoted by this abstract pathname
    // IMPORT: String new file name
    // EXPORT: The new MyFile object with the renamed filename (if rename
    //         succeed), or the old MyFile object (if rename fails)
    // NOTE: The built-in renameTo() method actually moves the file. I dont 
    //       want this, so I rewrite my renameTo() method    
    public MyFile renameTo (String newName, boolean forceDelete)
    {
        File temp = new File (this.getParent (), newName);
        boolean b;
            
        if (temp.exists () && forceDelete) {
            temp.delete ();
        }
            
        b = this.renameTo (temp);
            
        if (b == true) {
            return (new MyFile (temp));
        } else {
            System.err.println ("ERROR: Unable to rename file.");
            return this;
        }
    }
        
        
    // METHOD: renameTo()
    // PURPOSE: to rename the file denoted by this abstract pathname
    // IMPORT: MyFile object containing new file name
    // EXPORT: The new MyFile object with the renamed filename (if rename
    //         succeed), or the old MyFile object (if rename fails)
    // NOTE: The built-in renameTo() method actually moves the file. I dont 
    //       want this, so I rewrite my renameTo() method     
    public MyFile renameTo (MyFile f, boolean b)
    {
        return renameTo (f.getName (), b);
    }
        
        
    // METHOD: move ()
    // PURPOSE: to more correctly denote the built-in renameTo() method
    // IMPORT: File object with new file name
    // EXPORT: true if file successfully moved, false otherwise    
    public boolean moveTo (File f)
    {
        return super.renameTo (f);
    }
        

    // METHOD: createTempFile()
    // PURPOSE: to over-ride the original method to return MyFile object 
    //          instead of File object
    // IMPORT: String prefix, String suffix, MyFile object (denoting parent 
    //         directory for the temp file)
    // EXPORT: MyFile object for the temp file created
    public static MyFile createTempFile (String prefix, String sufix, MyFile directory)
    throws IOException
    {
        File f = File.createTempFile (prefix, sufix, (File)directory);
		
        return (new MyFile (f)); 
    }

        
    // METHOD: doubleToFileSize ()
    // PURPOSE: to format the imported number to its file size equivalence.
    // IMPORT: a number to be formated
    // EXPORT: String representation of the number in file size format
    public static String doubleToFileSize (double num)
    {	
        final double THOUSAND = 1000.0;

        DecimalFormat df = new DecimalFormat ("0.##");
        String multiplier = "bytes";

        if (num >= THOUSAND) {
            num /= THOUSAND;
            multiplier = "kb";
        }

        if (num >= THOUSAND) {
            num /= THOUSAND;
            multiplier = "Mb";
        }

        if (num >= THOUSAND) {
            num /= THOUSAND;
            multiplier = "Gb";
        }

        return (df.format(num) +" " +multiplier);
    }
}